@@ -33,173 +33,240 @@ from Products.Archetypes.atapi import *
 from Products.PyConBrasil.UIDRenamer import UIDRenamer
 from Products.PyConBrasil.config import *
 
-##code-section module-header #fill in your manual code here
 import transaction
 from Products.CMFCore.utils import getToolByName
-##/code-section module-header
+from Products.PyConBrasil import MessageFactory as _
+
 
 schema = Schema((
 
     StringField(
         name='nome',
         widget=StringWidget(
-            description="Informe o seu nome completo.",
-            label='Nome',
-            label_msgid='PyConBrasil_label_nome',
-            description_msgid='PyConBrasil_help_nome',
-            i18n_domain='PyConBrasil',
+            description=_(u'Informe o seu nome completo.'),
+            label=_(u'Nome'),
         ),
-        required=1
+        required=True,
+        schemata='Seus dados',
     ),
-
+    
+    StringField(
+        name='instituicao',
+        widget=StringWidget(
+            description=_(u'Informe o nome da instituição em que você estuda, trabalha ou representa.'),
+            condition="not:object/emPreInscricao",
+            label=_(u'Instituição'),
+        ),
+        schemata='Seus dados',
+    ),
+    
     StringField(
         name='sexo',
         widget=SelectionWidget(
-            description="Informe o seu sexo.",
-            label='Sexo',
-            label_msgid='PyConBrasil_label_sexo',
-            description_msgid='PyConBrasil_help_sexo',
-            i18n_domain='PyConBrasil',
+            description=_(u'Informe o seu sexo.'),
+            label=_(u'Sexo'),
         ),
-        enforceVocabulary=1,
-        vocabulary=['Feminino', 'Masculino'],
-        required=1
+        enforceVocabulary=True,
+        vocabulary_factory='pythonbrasil.sexo',
+        required=True,
+        schemata='Seus dados',
     ),
 
     StringField(
         name='email',
         widget=StringWidget(
-            label="E-Mail",
-            description="Informe o seu endereço eletrônico.",
-            label_msgid='PyConBrasil_label_email',
-            description_msgid='PyConBrasil_help_email',
-            i18n_domain='PyConBrasil',
+            label=_(u'E-Mail'),
+            description=_(u'Informe o seu endereço eletrônico.'),
         ),
-        required=1,
-        validators=('isEmail',)
+        required=True,
+        validators=('isEmail',),
+        schemata='Informações de contato',
     ),
-
+    
+    StringField(
+        name='twitter',
+        widget=StringWidget(
+            label=_(u'Twitter'),
+            description=_(u'Possui uma conta no Twitter, nos diga qual o seu usuário.'),
+        ),
+        required=False,
+        schemata='Informações de contato',
+    ),
+        
+    StringField(
+        name='site',
+        widget=StringWidget(
+            label=_(u'Site  pessoal / Blog'),
+            description=_(u'Caso tenha um site ou blog, por favor informe aqui o endereço, com o http://.'),
+        ),
+        required=False,
+        validators=('isURL',),
+        schemata='Informações de contato',
+    ),
+    
     StringField(
         name='telefone',
         widget=StringWidget(
-            description="Informe o seu telefone para contato em caso de necessidade. Incluindo o código DDD.",
+            description=_(u'Informe o seu telefone para contato em caso de necessidade. Incluindo o código DDD.'),
             size=14,
             maxlength=20,
-            label='Telefone',
-            label_msgid='PyConBrasil_label_telefone',
-            description_msgid='PyConBrasil_help_telefone',
-            i18n_domain='PyConBrasil',
-        )
+            label=_(u'Telefone'),
+        ),
+        schemata='Informações de contato',
     ),
-
+    
+    StringField(
+        name='endereco',
+        widget=StringWidget(
+            size=40,
+            maxlength=180,
+            description=_(u'Informe o endereço completo em que você reside. Será utilizado caso seja necessário enviar algo para você como por exemplo um brinde, ou o certificado de participação.'),
+            condition="not:object/emPreInscricao",
+            label=_(u'Endereço'),
+        ),
+        schemata='Seu endereço',
+    ),
+    
+    StringField(
+        name='cep',
+        widget=StringWidget(
+            size=10,
+            maxlength=9,
+            description=_(u'Por favor informe o cep do endereço da empresa'),
+            condition="not:object/emPreInscricao",
+            label=_(u'CEP'),
+        ),
+        schemata='Seu endereço',
+    ),
+    
     StringField(
         name='cidade',
         widget=StringWidget(
-            description="Informe o nome da cidade em que você reside.",
-            label='Cidade',
-            label_msgid='PyConBrasil_label_cidade',
-            description_msgid='PyConBrasil_help_cidade',
-            i18n_domain='PyConBrasil',
+            description=_(u'Informe o nome da cidade em que você reside.'),
+            label=_(u'Cidade'),
         ),
-        required=1
+        required=True,
+        schemata='Seu endereço',
     ),
 
     StringField(
         name='estado',
         widget=SelectionWidget(
-            description="Selecione o Estado em que você reside.",
-            label='Estado',
-            label_msgid='PyConBrasil_label_estado',
-            description_msgid='PyConBrasil_help_estado',
-            i18n_domain='PyConBrasil',
+            description=_(u'Selecione o Estado em que você reside.'),
+            label=_(u'Estado'),
         ),
-        enforceVocabulary=1,
-        vocabulary=ESTADOS,
-        required=1
+        enforceVocabulary=True,
+        vocabulary_factory='brasil.estados',
+        required=True,
+        schemata='Seu endereço',
+    ),
+    
+    StringField(
+        name='pais',
+        widget=SelectionWidget(
+            description=_(u'Informe o pais de sua residência.'),
+            label=_(u'País'),
+        ),
+        default='Brasil',
+        enforceVocabulary=True,
+        vocabulary_factory='brasil.paises',
+        required=True,
+        schemata='Seu endereço',
     ),
 
-    StringField(
-        name='endereco',
-        widget=StringWidget(
-            description="Informe o endereço completo em que você reside. Será utilizado caso seja necessário enviar algo para você como por exemplo o certificado de participação.",
-            condition="not:object/emPreInscricao",
-            label="Endereço",
-            label_msgid='PyConBrasil_label_endereco',
-            description_msgid='PyConBrasil_help_endereco',
-            i18n_domain='PyConBrasil',
-        )
-    ),
-
-    StringField(
-        name='instituicao',
-        widget=StringWidget(
-            description="Informe o nome da instituição em que você estuda, trabalha ou representa.",
-            condition="not:object/emPreInscricao",
-            label="Instituição",
-            label_msgid='PyConBrasil_label_instituicao',
-            description_msgid='PyConBrasil_help_instituicao',
-            i18n_domain='PyConBrasil',
-        )
-    ),
 
     StringField(
         name='tipo',
         widget=SelectionWidget(
-            description="Tipo da inscrição que está sendo realizada.",
+            description=_(u'Tipo da inscrição que está sendo realizada.'),
             condition="not:object/emPreInscricao",
-            label='Tipo',
-            label_msgid='PyConBrasil_label_tipo',
-            description_msgid='PyConBrasil_help_tipo',
-            i18n_domain='PyConBrasil',
+            label=_(u'Tipo'),
         ),
-        required=1,
-        vocabulary=(
-            ('1', 'Estudante ou Membro APyB'),
-            ('2', 'Membro SBC ou Membro ABRAWEB'),
-            ('3', 'Público em geral'),
-            ('4', 'Patrocinador'),
+        required=True,
+        enforceVocabulary=True,
+        default=3,
+        vocabulary_factory='pythonbrasil.tipo_inscricao',
+        schemata='Sua inscrição',
+    ),
+
+    StringField(
+        name='camiseta',
+        widget=SelectionWidget(
+            description=_(u'Por favor nos informe qual o tamanho da camiseta que você pretende receber'),
+            condition="not:object/emPreInscricao",
+            label=_(u'Tamanho da camiseta'),
         ),
+        required=True,
+        enforceVocabulary=True,
+        vocabulary_factory='pythonbrasil.camisetas',
+        schemata='Sua inscrição',
+    ),
+
+    StringField(
+        name='code',
+        widget=StringWidget(
+            description=_(u'Caso você tenha recebido um código de desconto do evento, o informe aqui.'),
+            condition="not:object/emPreInscricao",
+            label=_(u'Código de desconto'),
+        ),
+        schemata='Sua inscrição',
+    ),
+
+    BooleanField(
+        name='optin_evento',
+        widget=BooleanWidget(
+            label=_(u'Aceito receber informações relativas a PythonBrasil'),
+        ),
+        default=True,
+        schemata='Sua inscrição',
+    ),
+
+    BooleanField(
+        name='optin_parceiros',
+        widget=BooleanWidget(
+            label=_(u'Aceito receber informações dos patrocinadores do evento'),
+        ),
+        default=True,
+        schemata='Sua inscrição',
     ),
 
     BooleanField(
         name='paga',
         widget=BooleanWidget(
             visible=0,
-            label='Paga',
-            label_msgid='PyConBrasil_label_paga',
-            i18n_domain='PyConBrasil',
+            label=_(u'Paga'),
         )
     ),
-
+    
+    IntegerField(
+        name='valor_pago',
+        widget=IntegerWidget(
+            condition="object/getPaga",
+            label=_(u'Valor pago'),
+        )
+    ),
+    
     ReferenceField(
         name='treinamentos',
         widget=ReferenceWidget(
-            description="Selecione os treinamentos que você deseja participar.",
+            description=_(u'Selecione os treinamentos que você deseja participar.'),
             format="select",
-            visible=0,
+            visible=True,
             condition="not:object/emPreInscricao",
-            label='Treinamentos',
-            label_msgid='PyConBrasil_label_treinamentos',
-            description_msgid='PyConBrasil_help_treinamentos',
-            i18n_domain='PyConBrasil',
+            label=_(u'Treinamentos'),
         ),
         allowed_types=('Treinamento',),
-        multiValued=1,
+        multiValued=True,
         relationship='Inscricao_Treinamento'
     ),
 
 ),
 )
 
-##code-section after-local-schema #fill in your manual code here
-##/code-section after-local-schema
-
 Inscricao_schema = BaseSchema.copy() + \
     schema.copy()
 
-##code-section after-schema #fill in your manual code here
-
-Inscricao_schema['title'].required = 0
+Inscricao_schema['title'].required = False
 Inscricao_schema['title'].widget.visible = {'view':'invisible', 'edit':'invisible'}
 
 ##/code-section after-schema
@@ -209,10 +276,9 @@ class Inscricao(UIDRenamer, BaseContent):
     """
     security = ClassSecurityInfo()
     __implements__ = (getattr(UIDRenamer,'__implements__',()),) + (getattr(BaseContent,'__implements__',()),)
-
-    # This name appears in the 'add' box
+    
     archetype_name = 'Inscrição'
-
+    
     meta_type = 'Inscricao'
     portal_type = 'Inscricao'
     allowed_content_types = []
@@ -224,24 +290,27 @@ class Inscricao(UIDRenamer, BaseContent):
     suppl_views = ()
     typeDescription = "Inscrição de um participante no evento."
     typeDescMsgId = 'description_edit_inscricao'
-
+    
     _at_rename_after_creation = True
-
+    
     schema = Inscricao_schema
-    for schemata in ['settings','categorization','metadata','dates','ownership']:
+    for schemata in ['default','settings','categorization','metadata','dates','ownership']:
         for field in schema.getSchemataFields(schemata):
             field.widget.visible={'edit':'invisible','view':'invisible'}
-    ##code-section class-header #fill in your manual code here
-    ##/code-section class-header
-
-    # Methods
-
-    # Manually created methods
-
+    
     def Title(self):
         """Retorna o nome como título do objeto.
         """
         return self.getNome()
+    
+    def quantity(self):
+        ''' Return the number of inscritos
+        '''
+        return 1
+    
+    def nomesParticipantes(self):
+        return self.getTitle()
+
 
 
 def modify_fti(fti):
@@ -252,10 +321,3 @@ def modify_fti(fti):
     return fti
 
 registerType(Inscricao, PROJECTNAME)
-# end of class Inscricao
-
-##code-section module-footer #fill in your manual code here
-##/code-section module-footer
-
-
-
